package
Version:
v0.1.2
Opens a new window with list of versions in this module.
Published: Jun 23, 2025
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Info struct {
OS string `json:"os"`
Kernel string `json:"kernel"`
Arch string `json:"arch"`
CPUs int `json:"cpus"`
GoVersion string `json:"goVersion"`
Hostname string `json:"hostname"`
Uptime string `json:"uptime"`
Virtualization string `json:"virtualization,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.